==> CGAL-5.1-doc_html.tar.xz: doc_html/Polygon_mesh_processing/navtreeindex1.js <==
var NAVTREEINDEX1 =
{
"group__keep__connected__components__grp.html#gab238ffa71187b8fdcdeef48e71ee4b28":[1,0,1,3],
"group__keep__connected__components__grp.html#gabe2052b2281e1e628e68d8fea94be2d9":[1,0,1,1],
"group__keep__connected__components__grp.html#gad2546bc14c00bac66d87161a4044f871":[1,0,1,0],
"group__measure__grp.html":[1,0,5],
"group__measure__grp.html#ga28d930d2b4f62a5ac17797029e57772a":[1,0,5,5],
"group__measure__grp.html#ga5f88e84a8dc21da40b194b8c05ed3b4a":[1,0,5,0],
"group__measure__grp.html#ga6a1d7a825c09490b1e6613295343482b":[1,0,5,4],
"group__measure__grp.html#ga6da5119ce2c50729fda11a90ae7fb9ba":[1,0,5,2],
"group__measure__grp.html#ga766d9244b959bc25e419edb8b7c24842":[1,0,5,7],
"group__measure__grp.html#ga7e6384810b305b9df283bbf94fd9fd20":[1,0,5,1],
"group__measure__grp.html#ga85cebf8fbc7cb8930fd16aeee2878c7e":[1,0,5,8],
"group__measure__grp.html#ga8e778962db8e41dc145d70c5c4790e41":[1,0,5,6],
"group__measure__grp.html#gae1674775d9fecada7f25710f425cff3a":[1,0,5,3],
"hasModels.html":[4],
"index.html":[],
"index.html":[0],
"index.html#AHDExample":[0,10,0],
"index.html#CCExample":[0,9,0],
"index.html#Coref_section":[0,2],
"index.html#DetectFeaturesExample":[0,11,0],
"index.html#FixNMVerticeExample":[0,6,2,0],
"index.html#HFExample_1":[0,3,1,0],
"index.html#HFExample_2":[0,3,1,1],
"index.html#HFExamples":[0,3,1],
"index.html#HFPerformance":[0,3,2],
"index.html#HoleFillingAPI":[0,3,0],
"index.html#InsideExample":[0,4,1,0],
"index.html#Meshing":[0,1,0,0],
"index.html#MeshingAPI":[0,1,0],
"index.html#MeshingExample_1":[0,1,1,0],
"index.html#MeshingExample_2":[0,1,1,1],
"index.html#MeshingExamples":[0,1,1],
"index.html#NormalsExample":[0,7,0],
"index.html#NormalsExampleP":[0,7,0,1],
"index.html#NormalsExampleSM":[0,7,0,0],
"index.html#OrientingPolygonMeshes":[0,5,1],
"index.html#PMPAPI":[0,0,1],
"index.html#PMPConnectedComponents":[0,9],
"index.html#PMPDef":[0,0,0],
"index.html#PMPDetectFeatures":[0,11],
"index.html#PMPDistance":[0,10],
"index.html#PMPDoIntersect":[0,4,0],
"index.html#PMPDuplicateVertexBoundaryCycle":[0,6,3],
"index.html#PMPHistory":[0,12],
"index.html#PMPHoleFilling":[0,3],
"index.html#PMPInsideTest":[0,4,1],
"index.html#PMPIntroduction":[0,0],
"index.html#PMPLocationFunctions":[0,4,3],
"index.html#PMPManifoldness":[0,6,2],
"index.html#PMPMeshing":[0,1],
"index.html#PMPNormalComp":[0,7],
"index.html#PMPOrientation":[0,5],
"index.html#PMPOutline":[0,0,2],
"index.html#PMPPredicates":[0,4],
"index.html#PMPRepairing":[0,6],
"index.html#PMPSelIntersections":[0,4,0,0],
"index.html#PMPShapePredicates":[0,4,2],
"index.html#PMPSlicer":[0,8],
"index.html#PSRepairing":[0,6,0],
"index.html#PoissonDistanceExample":[0,10,1],
"index.html#PolygonSoupExample":[0,5,2],
"index.html#PolygonSoups":[0,5,0],
"index.html#Remeshing":[0,1,0,1],
"index.html#RemeshingExample_1":[0,1,1,2],
"index.html#SIExample":[0,4,0,1],
"index.html#SlicerExample":[0,8,0],
"index.html#Smoothing":[0,1,0,2],
"index.html#Stitching":[0,6,1],
"index.html#StitchingExample":[0,6,1,0],
"index.html#coref_bolop_subsec":[0,2,2],
"index.html#coref_clip":[0,2,4],
"index.html#coref_coref_subsec":[0,2,1],
"index.html#coref_def_subsec":[0,2,0],
"index.html#coref_ex_consq_subsec":[0,2,5,2],
"index.html#coref_ex_refine_subsec":[0,2,5,1],
"index.html#coref_ex_subsec":[0,2,5],
"index.html#coref_ex_union_subsec":[0,2,5,0],
"index.html#coref_valid_subsec":[0,2,3],
"modules.html":[1],
"pages.html":[],
"refines.html":[2],
"structCGAL_1_1Polygon__mesh__processing_1_1Corefinement_1_1Default__visitor.html":[1,0,10,0]
};

==> CGAL-5.2-doc_html.tar.xz: doc_html/Polygon_mesh_processing/navtreeindex1.js <==
var NAVTREEINDEX1 =
{
"group__keep__connected__components__grp.html":[1,0,1],
"group__keep__connected__components__grp.html#ga17cb532198888791f2ceb00666f4c1d4":[1,0,1,6],
"group__keep__connected__components__grp.html#ga48e7b3e6922ee78cf8ce801e3e325d9a":[1,0,1,4],
"group__keep__connected__components__grp.html#ga4b7d6fb132789998695d855f326a0fba":[1,0,1,7],
"group__keep__connected__components__grp.html#ga68c6c29dfc6a26a6a2f8befe6944f19d":[1,0,1,5],
"group__keep__connected__components__grp.html#ga7dd1414e9366fed26c1f12c12c376b39":[1,0,1,2],
"group__keep__connected__components__grp.html#gaac75eda5fb0a040c2b3cb8096ab8acb1":[1,0,1,8],
"group__keep__connected__components__grp.html#gab238ffa71187b8fdcdeef48e71ee4b28":[1,0,1,3],
"group__keep__connected__components__grp.html#gabe2052b2281e1e628e68d8fea94be2d9":[1,0,1,1],
"group__keep__connected__components__grp.html#gad2546bc14c00bac66d87161a4044f871":[1,0,1,0],
"group__measure__grp.html":[1,0,5],
"group__measure__grp.html#ga28d930d2b4f62a5ac17797029e57772a":[1,0,5,5],
"group__measure__grp.html#ga5f88e84a8dc21da40b194b8c05ed3b4a":[1,0,5,0],
"group__measure__grp.html#ga6a1d7a825c09490b1e6613295343482b":[1,0,5,4],
"group__measure__grp.html#ga6da5119ce2c50729fda11a90ae7fb9ba":[1,0,5,2],
"group__measure__grp.html#ga766d9244b959bc25e419edb8b7c24842":[1,0,5,7],
"group__measure__grp.html#ga7e6384810b305b9df283bbf94fd9fd20":[1,0,5,1],
"group__measure__grp.html#ga85cebf8fbc7cb8930fd16aeee2878c7e":[1,0,5,8],
"group__measure__grp.html#ga8e778962db8e41dc145d70c5c4790e41":[1,0,5,6],
"group__measure__grp.html#gae1674775d9fecada7f25710f425cff3a":[1,0,5,3],
"hasModels.html":[4],
"index.html":[],
"index.html":[0],
"index.html#AHDExample":[0,10,0],
"index.html#CCExample":[0,9,0],
"index.html#Coref_section":[0,2],
"index.html#DetectFeaturesExample":[0,11,0],
"index.html#FixNMVerticeExample":[0,6,2,0],
"index.html#HFExample_1":[0,3,1,0],
"index.html#HFExample_2":[0,3,1,1],
"index.html#HFExamples":[0,3,1],
"index.html#HFPerformance":[0,3,2],
"index.html#HoleFillingAPI":[0,3,0],
"index.html#InsideExample":[0,4,1,0],
"index.html#Meshing":[0,1,0,0],
"index.html#MeshingAPI":[0,1,0],
"index.html#MeshingExample_1":[0,1,1,0],
"index.html#MeshingExample_2":[0,1,1,1],
"index.html#MeshingExamples":[0,1,1],
"index.html#NormalsExample":[0,7,0],
"index.html#NormalsExampleP":[0,7,0,1],
"index.html#NormalsExampleSM":[0,7,0,0],
"index.html#OrientingPolygonMeshes":[0,5,1],
"index.html#PMPAPI":[0,0,1],
"index.html#PMPConnectedComponents":[0,9],
"index.html#PMPDef":[0,0,0],
"index.html#PMPDetectFeatures":[0,11],
"index.html#PMPDistance":[0,10],
"index.html#PMPDoIntersect":[0,4,0],
"index.html#PMPDuplicateVertexBoundaryCycle":[0,6,3],
"index.html#PMPHistory":[0,12],
"index.html#PMPHoleFilling":[0,3],
"index.html#PMPInsideTest":[0,4,1],
"index.html#PMPIntroduction":[0,0],
"index.html#PMPLocationFunctions":[0,4,3],
"index.html#PMPManifoldness":[0,6,2],
"index.html#PMPMeshing":[0,1],
"index.html#PMPNormalComp":[0,7],
"index.html#PMPOrientation":[0,5],
"index.html#PMPOutline":[0,0,2],
"index.html#PMPPredicates":[0,4],
"index.html#PMPRepairing":[0,6],
"index.html#PMPSelIntersections":[0,4,0,0],
"index.html#PMPShapePredicates":[0,4,2],
"index.html#PMPSlicer":[0,8],
"index.html#PSRepairing":[0,6,0],
"index.html#PoissonDistanceExample":[0,10,1],
"index.html#PolygonSoupExample":[0,5,2],
"index.html#PolygonSoups":[0,5,0],
"index.html#Remeshing":[0,1,0,1],
"index.html#RemeshingExample_1":[0,1,1,2],
"index.html#SIExample":[0,4,0,1],
"index.html#SlicerExample":[0,8,0],
"index.html#Smoothing":[0,1,0,2],
"index.html#Stitching":[0,6,1],
"index.html#StitchingExample":[0,6,1,0],
"index.html#coref_bolop_subsec":[0,2,2],
"index.html#coref_clip":[0,2,4],
"index.html#coref_coref_subsec":[0,2,1],
"index.html#coref_def_subsec":[0,2,0],
"index.html#coref_ex_consq_subsec":[0,2,5,2],
"index.html#coref_ex_refine_subsec":[0,2,5,1],
"index.html#coref_ex_subsec":[0,2,5],
"index.html#coref_ex_union_subsec":[0,2,5,0],
"index.html#coref_valid_subsec":[0,2,3],
"modules.html":[1],
"pages.html":[],
"refines.html":[2],
"structCGAL_1_1Polygon__mesh__processing_1_1Corefinement_1_1Default__visitor.html":[1,0,10,0],
"structCGAL_1_1Polygon__mesh__processing_1_1Triangulate__faces_1_1Default__visitor.html":[1,0,3,0],
"structCGAL_1_1Polygon__mesh__processing_1_1Triangulate__faces_1_1Default__visitor.html#a32aeb88124a138d10e33313ac0b7e6b1":[1,0,3,0,4],
"structCGAL_1_1Polygon__mesh__processing_1_1Triangulate__faces_1_1Default__visitor.html#a5c1cfc5b2a3546a903b6e801a4fd5b44":[1,0,3,0,2],
"structCGAL_1_1Polygon__mesh__processing_1_1Triangulate__faces_1_1Default__visitor.html#a79904a3b9d710f998ea2a32fac7fa55b":[1,0,3,0,0],
"structCGAL_1_1Polygon__mesh__processing_1_1Triangulate__faces_1_1Default__visitor.html#aa4a99fcd42e1301e5360777b2381ab9e":[1,0,3,0,1],
"structCGAL_1_1Polygon__mesh__processing_1_1Triangulate__faces_1_1Default__visitor.html#af08505864e846411fc0451d829960d63":[1,0,3,0,3]
};
